==> servicemix-cxf-bc-3.3.1.12-fuse-installer.zip: uri/helloworld/ObjectFactory.java <==

package uri.helloworld;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the uri.helloworld package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: uri.helloworld
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link HelloHeader }
     * 
     */
    public HelloHeader createHelloHeader() {
        return new HelloHeader();
    }

    /**
     * Create an instance of {@link HelloRequest }
     * 
     */
    public HelloRequest createHelloRequest() {
        return new HelloRequest();
    }

    /**
     * Create an instance of {@link HelloResponse }
     * 
     */
    public HelloResponse createHelloResponse() {
        return new HelloResponse();
    }

    /**
     * Create an instance of {@link HelloFault }
     * 
     */
    public HelloFault createHelloFault() {
        return new HelloFault();
    }

}

==> servicemix-cxf-bc-3.3.1.25-fuse-installer.zip: uri/helloworld/ObjectFactory.java <==

package uri.helloworld;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the uri.helloworld package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: uri.helloworld
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link HelloResponse }
     * 
     */
    public HelloResponse createHelloResponse() {
        return new HelloResponse();
    }

    /**
     * Create an instance of {@link HelloFault }
     * 
     */
    public HelloFault createHelloFault() {
        return new HelloFault();
    }

    /**
     * Create an instance of {@link HelloHeader }
     * 
     */
    public HelloHeader createHelloHeader() {
        return new HelloHeader();
    }

    /**
     * Create an instance of {@link HelloRequest }
     * 
     */
    public HelloRequest createHelloRequest() {
        return new HelloRequest();
    }

    /**
     * Create an instance of {@link ImplicitHeader }
     * 
     */
    public ImplicitHeader createImplicitHeader() {
        return new ImplicitHeader();
    }

}
